#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-core
version:              1.6.28.0
visibility:           public
id:                   yesod-core-1.6.28.0-329Uf5FGYP7GZeTKBeNL5X
key:                  yesod-core-1.6.28.0-329Uf5FGYP7GZeTKBeNL5X
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  1008de01bf133d14a1ff7928aa59b3a0
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.28.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.28.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.28.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.28.0-329Uf5FGYP7GZeTKBeNL5X
depends:
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR
    attoparsec-aeson-2.2.0.1-59riOYvpER62CbYeMTftYk
    auto-update-0.1.6-1z9T2zyzYhC25XNZwV9BQp base-4.18.2.1
    blaze-html-0.9.2.0-PSPLizehIBK0KyrDun70k
    blaze-markup-0.8.3.0-En1LhSl79346pvouIeUq7J bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Gzh99I2Ds5LB1yZuFXcZ2A
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    clientsession-0.9.3.0-4NDwZs0AqJiGIrIryCYfmy
    conduit-1.3.6.1-F67YktQmHRqJ5R9QX7ucHV
    conduit-extra-1.3.8-6O6CtrkaMBHHbx4pVlP0Hf containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    fast-logger-3.2.4-IxoRJWc3eEqAy4H5XhaMjJ
    http-types-0.12.4-LSgWFg4mVle7jKIO2vdgXi
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-logger-0.3.42-H1jqZ8KVO5j3q4XyH44lmL mtl-2.3.1
    parsec-3.1.16.1 path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    primitive-0.9.1.0-Dm8O45wtcqd5eoiJyOalCK
    random-1.2.1.3-IIwS2aSfjMyGbtdCPZwDHA
    resourcet-1.2.6-LJgXHkWLt2tDuo3wpypfir
    shakespeare-2.1.7.1-IabZuHrxNmOG3MOVpkDAJn
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-BZMXqomGfYu4rulQDFCFZv
    unliftio-0.2.25.1-2ijZcbxfdeVCmMwCRtThrP
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1
    vector-0.13.2.0-B5QnucNm6YY8XIvh7YleVY
    wai-3.2.4-7vzMwDkBBVH69wuxH7kNR
    wai-extra-3.1.18-KcAY2Y0n4vdH5SyrKeSFD6
    wai-logger-2.5.0-9d0i4PLduDJ29qKHFYSqnH
    warp-3.4.0-DdLeV7x2DjaFjuKbDUU9vi
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

